# Changelog
All notable changes to this project will be documented in this file

## 0.2.0 - 2021-04-19

### Added

- New yak log logo drawn by my sister

### Changed

- Updated package metadata
- Rewrote parser to use a 2-step method that is more flexible.
    - Parser can now handle code blocks.
    - Parser can now handle setext-style headers and H2s not conforming to the
      schema.

## 0.1.0 - 2021-04-16

First release

### Added

- `yaclog.read()` method to parse changelog files
